@@ -135,6 +135,41 @@ DBTransformDiagonal(oldtype, trans)
     return dinfo;
 }
 
+/*
+ *-----------------------------------------------------------------
+ * DBInvTransformDiagonal --
+ *
+ *	This is the same as the routine above, but finds the
+ *	tranformation of a diagonal in a parent cell as seen
+ *	from the child's coordinate system.  This comes down
+ *	to merely swapping transform components b and d, since
+ *	translation is not considered.
+ *
+ *-----------------------------------------------------------------
+ */
+
+TileType
+DBInvTransformDiagonal(oldtype, trans)
+    TileType oldtype;
+    Transform *trans;
+{
+    TileType dinfo;
+    int o1, o2, o3, dir, side;
+	
+    o1 = ((trans->t_e > 0) || (trans->t_b > 0)) ? 1 : 0;
+    o2 = ((trans->t_a > 0) || (trans->t_d > 0)) ? 1 : 0;
+    o3 = (trans->t_a != 0) ? 1 : 0;
+    dir = (oldtype & TT_DIRECTION) ? 1 : 0;
+    side = ((oldtype & TT_SIDE) ? 1 : 0) ^ o2 ^ (dir | o3);
+    dir ^= o1 ^ o2;
+
+    dinfo = TT_DIAGONAL;
+    if (side) dinfo |= TT_SIDE;
+    if (dir) dinfo |= TT_DIRECTION;
+
+    return dinfo;
+}
+
 #endif
 
 
